@@ -280,12 +280,7 @@ class Customer(Resource):
             # If client type is XERO
             elif super().get_client_type() == super().XERO:
 
-                contacts = {}
-
-                if 'type' in payload.keys():
-                    contacts.update({
-                        "IsSupplier": payload.get("type", False)
-                    })
+                contacts = {"IsSupplier": False}
 
                 if 'first_name' in payload.keys() and 'last_name' in payload.keys():
                     contacts.update({
